and again
[bootstrapfs.git] / build.sh
index d773b61..371faa8 100755 (executable)
--- a/build.sh
+++ b/build.sh
@@ -1,14 +1,11 @@
 #!/bin/bash
 #
-# Build bootstrapfs-*.tar.bz2, the reference image(s) for PlanetLab nodes.
+# Build tgz root image for PlanetLab nodes.
 #
 # Mark Huang <mlhuang@cs.princeton.edu>
 # Marc E. Fiuczynski <mef@cs.princeton.edu>
 # Copyright (C) 2005-2007 The Trustees of Princeton University
 #
-# $Id: buildnode.sh,v 1.12.6.1 2007/08/30 20:09:20 mef Exp $
-#
-
 
 #
 # This will build the bootstrafs-*.tar.bz2 images, which comprises
@@ -16,6 +13,7 @@
 # which is made up of just the additional files needed for a ${NAME} nodegroup 
 # node.
 #
+# It is expected to be in sync with the getNodeFlavour PLCAPI method
 
 PATH=/sbin:/bin:/usr/sbin:/usr/bin
 
@@ -40,6 +38,9 @@ shift $shiftcount
 # expecting fcdistro and pldistro on the command line
 pldistro=$1; shift
 fcdistro=${pl_DISTRO_NAME}
+arch=${pl_DISTRO_ARCH}
+nodefamily=${pldistro}-${fcdistro}-${arch}
+extensionfamily=${fcdistro}-${arch}
 
 # Do not tolerate errors
 set -e
@@ -49,36 +50,35 @@ set -e
 # would like to pretend that we are.
 export PL_BOOTCD=1
 
# Populate a minimal /dev and then the files for the base bootstrapfs content
 vref=${PWD}/base
 install -d -m 755 ${vref}
 pl_root_makedevs $vref
 
-pkgsfile=$(pl_locateDistroFile ../build/ ${pldistro} bootstrapfs.pkgs)
-echo "--------START BUILDING PlanetLab-Bootstrap: $(date)"
+pkgsfile=$(pl_locateDistroFile ../build/ ${pldistro} nodeimage.pkgs)
+echo "* Building nodeimage for ${pldistro}: $(date)"
 # -k = exclude kernel* packages
 pl_root_mkfedora ${vref} ${pldistro} $pkgsfile
 
 # optionally invoke a post processing script after packages from
 # $pkgsfile have been installed
-pkgsdir=$(dirname $pkgsfile)
-pkgsname=$(basename $pkgsfile .pkgs)
-postfile="${pkgsdir}/${pkgsname}.post"
-[ -f $postfile ] && /bin/bash $postfile ${vref} || :
+postfile=$(pl_locateDistroFile ../build/ ${pldistro} nodeimage.post || : )
+[ -f $postfile ] && { echo "Running post install file $postfile" ; /bin/bash $postfile ${vref} || : ; }
 
-once=1
+displayed=""
 
-# for distros that do not define bootstrapfs variants
-pkgs_count=$(ls ../build/config.${pldistro}/bootstrapfs-*.pkgs 2> /dev/null | wc -l)
-[ $pkgs_count -gt 0 ] && for pkgs in $(ls ../build/config.${pldistro}/bootstrapfs-*.pkgs); do
-    NAME=$(basename $pkgs .pkgs | sed -e s,bootstrapfs-,,)
+# for distros that do define node extensions
+pkgs_count=$(ls ../build/config.${pldistro}/nodeimage-*.pkgs 2> /dev/null | wc -l)
+[ $pkgs_count -gt 0 ] && for pkgs in $(ls ../build/config.${pldistro}/nodeimage-*.pkgs); do
+    NAME=$(basename $pkgs .pkgs | sed -e s,nodeimage-,,)
 
-    if [ $once -eq 1 ] ; then
-       once=0
-       echo "--------CREATING PlanetLab-Bootstrap SUBPACKAGES"
-    fi
+    [ -z "$displayed" ] && echo "* Handling ${pldistro} nodeimage extensions"
+    displayed=true
+
+    extension_plain=nodeimage-${NAME}-${extensionfamily}.tar
+    extension_name=nodeimage-${NAME}-${extensionfamily}.tar.bz2
 
-    echo "--------START BUILDING PlanetLab-Bootstrap-${NAME}: $(date)"
+    echo "* Start Building $extension_name: $(date)"
 
     # "Parse" out the packages and groups for yum
     packages=$(pl_getPackages $fcdistro $pldistro $pkgs)
@@ -96,7 +96,11 @@ pkgs_count=$(ls ../build/config.${pldistro}/bootstrapfs-*.pkgs 2> /dev/null | wc
 
     # Install the system vserver specific packages
     [ -n "$packages" ] && yum -c ${vdir}/etc/mkfedora-yum.conf --installroot=${vdir} -y install $packages
-    [ -n "$groups" ] && yum -c ${vdir}/etc/mkfedora-yum.conf --installroot=${vdir} -y groupinstall $groups
+    for group_plus in $groups; do
+       group=$(echo $group_plus | sed -e "s,+++, ,g")
+        yum -c ${vdir}/etc/mkfedora-yum.conf --installroot=${vdir} -y groupinstall "$group"
+    done
+
 
     if [ -f "${vdir}/proc/cpuinfo" ] ; then
         echo "WARNING: some RPM appears to have mounted /proc in ${NAME}. Unmounting it!"
@@ -105,11 +109,8 @@ pkgs_count=$(ls ../build/config.${pldistro}/bootstrapfs-*.pkgs 2> /dev/null | wc
 
     # optionally invoke a post processing script after packages from
     # $pkgs have been installed
-    pkgsdir=$(dirname $pkgs)
-    pkgsname=$(basename $pkgs .pkgs)
-    postfile="${pkgsdir}/${pkgsname}.post"
-    [ -f $postfile ] && /bin/bash $postfile ${vdir} || :
-
+    postfile=$(pl_locateDistroFile ../build/ ${pldistro} nodeimage-${NAME}.post || : )
+    [ -f $postfile ] && { echo "Running post install file $postfile" ; /bin/bash $postfile ${vdir} || : ; }
 
     # Create a copy of the ${NAME} bootstrap filesystem w/o the base
     # bootstrap filesystem and make it smaller.  This is a three step
@@ -139,19 +140,26 @@ pkgs_count=$(ls ../build/config.${pldistro}/bootstrapfs-*.pkgs 2> /dev/null | wc
     rm -f  ${vdir}.changes
     mv ${vdir}-tmp ${vdir}
     
-    echo "--------STARTING tar'ing bootstrapfs-${NAME}-${pl_DISTRO_ARCH}.tar.bz2: $(date)"
-    tar -cpjf ${pldistro}-filesystems/bootstrapfs-${NAME}-${pl_DISTRO_ARCH}.tar.bz2 -C ${vdir} .
-    echo "--------FINISHED tar'ing bootstrapfs-${NAME}-${pl_DISTRO_ARCH}.tar.bz2: $(date)"
-    echo "--------DONE BUILDING bootstrapfs-${NAME}-${pl_DISTRO_ARCH}: $(date)"
+    echo -n "* tar $extension_name s=$(date +%H-%M-%S)"
+    tar -cpf ${pldistro}-filesystems/$extension_plain -C ${vdir} .
+    echo -n " m=$(date +%H-%M-%S) "
+    bzip2 --compress --stdout ${pldistro}-filesystems/$extension_plain > ${pldistro}-filesystems/$extension_name
+    echo " e=$(date +%H-%M-%S) "
 done
 
 # Build the base Bootstrap filesystem
 # clean out yum cache to reduce space requirements
 yum -c ${vref}/etc/mkfedora-yum.conf --installroot=${vref} -y clean all
-
-echo "--------STARTING tar'ing bootstrapfs-${pldistro}-${pl_DISTRO_ARCH}.tar.bz2: $(date)"
-tar -cpjf bootstrapfs-${pldistro}-${pl_DISTRO_ARCH}.tar.bz2 -C ${vref} .
-echo "--------FINISHED tar'ing bootstrapfs-${pldistro}-${pl_DISTRO_ARCH}.tar.bz2: $(date)"
-echo "--------DONE BUILDING PlanetLab-Bootstrap: $(date)"
+# create stamp on node image to help out node upgrades in the future
+mkdir -p ${vref}/etc/planetlab
+echo ${nodefamily} > ${vref}/etc/planetlab/nodefamily
+
+bootstrapfs_plain=bootstrapfs-${nodefamily}.tar
+bootstrapfs_name=bootstrapfs-${nodefamily}.tar.bz2
+echo -n "* tar $bootstrapfs_name s=$(date +%H-%M-%S)"
+tar -cpf $bootstrapfs_plain -C ${vref} .
+echo -n " m=$(date +%H-%M-%S) "
+bzip2 --compress --stdout $bootstrapfs_plain > $bootstrapfs_name
+echo " e=$(date +%H-%M-%S) "
 
 exit 0
@@ -49,36 +50,35 @@ set -e
 export PL_BOOTCD=1
 
-# Populate a minimal /dev and then the files for the base bootstrapfs content
+# Populate a minimal /dev and then the files for the base nodeimage content
 vref=${PWD}/base
 install -d -m 755 ${vref}